@@ -3,6 +3,8 @@ import com.vividsolutions.jump.io.ShapefileReader;
 import com.vividsolutions.jump.feature.FeatureCollection;
 import com.vividsolutions.jump.feature.Feature;
 import com.vividsolutions.jts.geom.Coordinate;
+import com.vividsolutions.jts.geom.MultiPolygon;
+import com.vividsolutions.jts.geom.Geometry;
 import com.vividsolutions.jts.simplify.TopologyPreservingSimplifier;
 import com.vividsolutions.jts.operation.distance.DistanceOp;
 
@@ -14,6 +16,8 @@ import Jama.Matrix;
 import javax.swing.*;
 
 /**
+ * Compute country distances based on CShapes polygons
+ * to be used from the cshapes R package
  * @author Nils Weidmann (nils.weidmann@gmail.com)
  */
 public class CountryDistancer {
@@ -130,8 +134,6 @@ public class CountryDistancer {
 		ArrayList<Feature> flist = getRelevantFeatures();
 
 		Matrix result = new Matrix(flist.size(), flist.size());
-		int total = (flist.size() * (flist.size()-1))/2;
-		int counter = 0;
 		for (int i=0; i<flist.size()-1; i++) {
 			Feature f1 = flist.get(i);
 			for (int j=i+1; j<flist.size(); j++) {
@@ -139,7 +141,6 @@ public class CountryDistancer {
 				double dist = distanceFeatures(f1, f2);
 				result.set(i,j,dist);
 				result.set(j,i,dist);
-				counter++;
 			}
 		}
 		return result.getColumnPackedCopy();
@@ -150,8 +151,6 @@ public class CountryDistancer {
 		ArrayList<Feature> flist = getRelevantFeatures();
 
 		Matrix result = new Matrix(flist.size(), flist.size());
-		int total = (flist.size() * (flist.size()-1))/2;
-		int counter = 0;
 		for (int i=0; i<flist.size()-1; i++) {
 			Coordinate cent1 = flist.get(i).getGeometry().getCentroid().getCoordinate();
 			for (int j=i+1; j<flist.size(); j++) {
@@ -159,7 +158,6 @@ public class CountryDistancer {
 				double dist = distanceCoordinates(cent1, cent2);
 				result.set(i,j,dist);
 				result.set(j,i,dist);
-				counter++;
 			}
 		}
 		return result.getColumnPackedCopy();
@@ -170,8 +168,6 @@ public class CountryDistancer {
 		ArrayList<Feature> flist = getRelevantFeatures();
 
 		Matrix result = new Matrix(flist.size(), flist.size());
-		int total = (flist.size() * (flist.size()-1))/2;
-		int counter = 0;
 		for (int i=0; i<flist.size()-1; i++) {
 
 			double caplong1 = (Double) flist.get(i).getAttribute("CAPLONG");
@@ -187,36 +183,34 @@ public class CountryDistancer {
 				double dist = distanceCoordinates(cap1, cap2);
 				result.set(i,j,dist);
 				result.set(j,i,dist);
-
-				counter++;
 			}
 		}
 		return result.getColumnPackedCopy();
 	}
 
 
-	private double distanceFeatures(Feature f1, Feature f2) {
+    private double distanceFeatures(Feature f1, Feature f2) {
 
-		Coordinate[] coords1 = f1.getGeometry().getCoordinates();
-		Coordinate[] coords2 = f2.getGeometry().getCoordinates();
+        Coordinate[] coords1 = f1.getGeometry().getCoordinates();
+        Coordinate[] coords2 = f2.getGeometry().getCoordinates();
 
-		double minDist = Double.MAX_VALUE;
+        double minDist = Double.MAX_VALUE;
 
-		for (int i = 0; i < coords1.length; i++) {
-			Coordinate c1 = coords1[i];
-			for (int j = 0; j < coords2.length; j++) {
-				Coordinate c2 = coords2[j];
-				double dist = distanceCoordinates(c1, c2);
-				if (dist <= 0) return 0;
-				if (dist<minDist) minDist = dist;
-			}
-		}
+        for (int i = 0; i < coords1.length; i++) {
+            Coordinate c1 = coords1[i];
+            for (int j = 0; j < coords2.length; j++) {
+                Coordinate c2 = coords2[j];
+                double dist = distanceCoordinates(c1, c2);
+                if (dist <= 0) return 0;
+                if (dist<minDist) minDist = dist;
+            }
+        }
 
-		return minDist;
-	}
+        return minDist;
+    }
 
-	private double distanceCoordinates(Coordinate c1, Coordinate c2) {
-		final double fromLon = Math.toRadians(c1.x);
+    private double distanceCoordinates(Coordinate c1, Coordinate c2) {
+        final double fromLon = Math.toRadians(c1.x);
         final double fromLat = Math.toRadians(c1.y);
         final double toLon = Math.toRadians(c2.x);
         final double toLat = Math.toRadians(c2.y);
@@ -227,7 +221,7 @@ public class CountryDistancer {
 
     // for testing only
 	public static void main(String[] args) {
-		CountryDistancer cd = new CountryDistancer("/Users/nilsw/R/mylibraries/cshapes/inst", 2008, 1, 1, 0.2, false);
+		CountryDistancer cd = new CountryDistancer("/Users/nilsw/Projects/CShapes/R-lib/cshapes/inst", 2008, 1, 1, 0.2, false);
 		double[] m = cd.getMinDistMatrix();
 	}
 
